@@ -1,6 +1,12 @@
 package Text::Mecabist::Document;
 use strict;
 use warnings;
+
+use overload (
+    q{""} => 'stringify',
+    fallback => 1,
+);
+
 use Moo;
 
 has count => (
@@ -29,6 +35,11 @@ sub each {
     }
 }
 
+sub stringify {
+    my ($self) = @_;
+    $self->join('text');
+}
+
 sub join {
     my ($self, $key) = @_;
     
